@@ -143,7 +143,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::functionCallI
     ItemList resultingItems;
 
     // gather additional items to show above the real ones (for parameters, and stuff)
-    FunctionDeclaration* functionCalled = 0;
+    FunctionDeclaration* functionCalled = nullptr;
     DUChainReadLocker lock;
     auto v = visitorForString(m_guessTypeOfExpression, m_duContext.data());
     if ( ! v || ! v->lastDeclaration() ) {
@@ -175,7 +175,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::functionCallI
     if ( depth() != 1 || ! functionCalled ) {
         return resultingItems;
     }
-    if ( DUContext* args = DUChainUtils::getArgumentContext(functionCalled) ) {
+    if ( DUContext* args = DUChainUtils::argumentContext(functionCalled) ) {
         int normalParameters = args->localDeclarations().count() - functionCalled->defaultParametersSize();
         if ( normalParameters > m_alreadyGivenParametersCount ) {
             qCDebug(KDEV_PYTHON_CODECOMPLETION) << "Not at default arguments yet";
@@ -218,7 +218,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::defineItems()
 
     bool isOwnContext = true;
     foreach ( DUContext* c, baseClassContexts ) {
-        QList<DeclarationDepthPair> declarations = c->allDeclarations(
+        const auto declarations = c->allDeclarations(
             CursorInRevision::invalid(), m_duContext->topContext(), false
         );
         foreach ( const DeclarationDepthPair& d, declarations ) {
@@ -234,7 +234,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::defineItems()
                 }
                 existingIdentifiers << identifier;
                 QStringList argumentNames;
-                DUContext* argumentsContext = DUChainUtils::getArgumentContext(funcDecl);
+                DUContext* argumentsContext = DUChainUtils::argumentContext(funcDecl);
                 if ( argumentsContext ) {
                     foreach ( Declaration* argument, argumentsContext->localDeclarations() ) {
                         argumentNames << argument->identifier().toString();
@@ -266,8 +266,8 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::raiseItems()
     }
     Declaration* base = declarations.first();
     IndexedType baseType = base->abstractType()->indexed();
-    QList<DeclarationDepthPair> validDeclarations;
-    ClassDeclaration* current = 0;
+    QVector<DeclarationDepthPair> validDeclarations;
+    ClassDeclaration* current = nullptr;
     StructureType::Ptr type;
     auto decls = m_duContext->topContext()->allDeclarations(CursorInRevision::invalid(), m_duContext->topContext());
     foreach ( const DeclarationDepthPair d, decls ) {
@@ -305,7 +305,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::inheritanceIt
     ItemList resultingItems;
     DUChainReadLocker lock;
     qCDebug(KDEV_PYTHON_CODECOMPLETION) << "InheritanceCompletion";
-    QList<DeclarationDepthPair> declarations;
+    QVector<DeclarationDepthPair> declarations;
     if ( ! m_guessTypeOfExpression.isEmpty() ) {
         // The class completion is a member access
         auto v = visitorForString(m_guessTypeOfExpression, m_duContext.data());
@@ -321,7 +321,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::inheritanceIt
     else {
         declarations = m_duContext->allDeclarations(m_position, m_duContext->topContext());
     }
-    QList<DeclarationDepthPair> remainingDeclarations;
+    QVector<DeclarationDepthPair> remainingDeclarations;
     foreach ( const DeclarationDepthPair& d, declarations ) {
         Declaration* r = Helper::resolveAliasDeclaration(d.first);
         if ( r && r->topContext() == Helper::getDocumentationFileContext() ) {
@@ -485,7 +485,7 @@ PythonCodeCompletionContext::ItemList PythonCodeCompletionContext::classMemberIn
     if ( ! decl ) {
         return resultingItems;
     }
-    DUContext* args = DUChainUtils::getArgumentContext(duContext()->owner());
+    DUContext* args = DUChainUtils::argumentContext(duContext()->owner());
     if ( ! args ) {
         return resultingItems;
     }
@@ -612,7 +612,7 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::completionItems(bo
             return ItemList();
         }
         DUChainReadLocker lock;
-        QList<DeclarationDepthPair> declarations = m_duContext->allDeclarations(m_position, m_duContext->topContext());
+        auto declarations = m_duContext->allDeclarations(m_position, m_duContext->topContext());
         foreach ( const DeclarationDepthPair& d, declarations ) {
             if ( d.first && d.first->context()->type() == DUContext::Class ) {
                 declarations.removeAll(d);
@@ -645,8 +645,7 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::getMissingIncludeI
         return items;
     }
 
-    Declaration* existing = Helper::declarationForName(QualifiedIdentifier(components.first()),
-                                                       RangeInRevision(m_position, m_position),
+    Declaration* existing = Helper::declarationForName(components.first(), m_position,
                                                        DUChainPointer<const DUContext>(m_duContext.data()));
     if ( existing ) {
         // There's already a declaration for the first component; no need to suggest it
@@ -677,12 +676,12 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::getMissingIncludeI
     return items;
 }
 
-QList<CompletionTreeItemPointer> PythonCodeCompletionContext::declarationListToItemList(QList<DeclarationDepthPair> declarations, int maxDepth)
+QList<CompletionTreeItemPointer> PythonCodeCompletionContext::declarationListToItemList(const QVector<DeclarationDepthPair>& declarations, int maxDepth)
 {
     QList<CompletionTreeItemPointer> items;
     
     DeclarationPointer currentDeclaration;
-    Declaration* checkDeclaration = 0;
+    Declaration* checkDeclaration = nullptr;
     int count = declarations.length();
     for ( int i = 0; i < count; i++ ) {
         if ( maxDepth && maxDepth > declarations.at(i).second ) {
@@ -691,7 +690,7 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::declarationListToI
         }
         currentDeclaration = DeclarationPointer(declarations.at(i).first);
         
-        PythonDeclarationCompletionItem* item = 0;
+        PythonDeclarationCompletionItem* item = nullptr;
         checkDeclaration = Helper::resolveAliasDeclaration(currentDeclaration.data());
         if ( ! checkDeclaration ) {
             continue;
@@ -713,7 +712,8 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::declarationListToI
 
 QList< CompletionTreeItemPointer > PythonCodeCompletionContext::declarationListToItemList(QList< Declaration* > declarations)
 {
-    QList<DeclarationDepthPair> fakeItems;
+    QVector<DeclarationDepthPair> fakeItems;
+    fakeItems.reserve(declarations.size());
     foreach ( Declaration* d, declarations ) {
         fakeItems << DeclarationDepthPair(d, 0);
     }
@@ -781,10 +781,10 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::getCompletionItems
     }
     // the PublicOnly will filter out non-explictly defined __get__ etc. functions inherited from object
     auto searchContexts = Helper::internalContextsForClass(cls, m_duContext->topContext(), Helper::PublicOnly);
-    QList<DeclarationDepthPair> keepDeclarations;
+    QVector<DeclarationDepthPair> keepDeclarations;
     foreach ( const DUContext* currentlySearchedContext, searchContexts ) {
         qCDebug(KDEV_PYTHON_CODECOMPLETION) << "searching context " << currentlySearchedContext->scopeIdentifier() << "for autocompletion items";
-        QList<DeclarationDepthPair> declarations = currentlySearchedContext->allDeclarations(CursorInRevision::invalid(),
+        const auto declarations = currentlySearchedContext->allDeclarations(CursorInRevision::invalid(),
                                                                                                 m_duContext->topContext(),
                                                                                                 false);
         qCDebug(KDEV_PYTHON_CODECOMPLETION) << "found" << declarations.length() << "declarations";
@@ -898,10 +898,10 @@ QList<CompletionTreeItemPointer> PythonCodeCompletionContext::findIncludeItems(Q
 
 DUContext* PythonCodeCompletionContext::internalContextForDeclaration(TopDUContext* topContext, QStringList remainingIdentifiers)
 {
-    Declaration* d = 0;
+    Declaration* d = nullptr;
     DUContext* c = topContext;
     if ( ! topContext ) {
-        return 0;
+        return nullptr;
     }
     if ( remainingIdentifiers.isEmpty() ) {
         return topContext;
@@ -910,7 +910,7 @@ DUContext* PythonCodeCompletionContext::internalContextForDeclaration(TopDUConte
         QList< Declaration* > decls = c->findDeclarations(QualifiedIdentifier(remainingIdentifiers.first()));
         remainingIdentifiers.removeFirst();
         if ( decls.isEmpty() ) {
-            return 0;
+            return nullptr;
         }
         d = decls.first();
         if ( (c = d->internalContext()) ) {
@@ -918,10 +918,10 @@ DUContext* PythonCodeCompletionContext::internalContextForDeclaration(TopDUConte
                 return c;
             }
         }
-        else return 0;
+        else return nullptr;
         
     } while ( d && ! remainingIdentifiers.isEmpty() );
-    return 0;
+    return nullptr;
 }
 
 QList<CompletionTreeItemPointer> PythonCodeCompletionContext::includeItemsForSubmodule(QString submodule)
@@ -1030,7 +1030,7 @@ PythonCodeCompletionContext::PythonCodeCompletionContext(DUContextPointer contex
     : CodeCompletionContext(context, text, position, depth)
     , m_operation(PythonCodeCompletionContext::DefaultCompletion)
     , m_itemTypeHint(NoHint)
-    , m_child(0)
+    , m_child(nullptr)
     , m_followingText(followingText)
     , m_position(position)
 {
